summaryrefslogtreecommitdiffstats
path: root/chrome/browser/net
diff options
context:
space:
mode:
authorwillchan@chromium.org <willchan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-07-20 15:48:53 +0000
committerwillchan@chromium.org <willchan@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-07-20 15:48:53 +0000
commit9abfa1903f72e0735c9c1ef6570eef94f26eb4a7 (patch)
tree0a9cc60eebf84295d1a0dd5896d80f96b9461f75 /chrome/browser/net
parent056f879b0a2a3281818bda56011081a6c683208e (diff)
downloadchromium_src-9abfa1903f72e0735c9c1ef6570eef94f26eb4a7.zip
chromium_src-9abfa1903f72e0735c9c1ef6570eef94f26eb4a7.tar.gz
chromium_src-9abfa1903f72e0735c9c1ef6570eef94f26eb4a7.tar.bz2
Deprecate Profile::GetDefaultRequestContext().
Make it private and establish a friend whitelist for existing users. BUG=64339 TEST=none Review URL: http://codereview.chromium.org/7438002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@93200 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/net')
-rw-r--r--chrome/browser/net/preconnect.cc3
-rw-r--r--chrome/browser/net/sdch_dictionary_fetcher.cc3
-rw-r--r--chrome/browser/net/websocket_experiment/websocket_experiment_task.cc16
3 files changed, 12 insertions, 10 deletions
diff --git a/chrome/browser/net/preconnect.cc b/chrome/browser/net/preconnect.cc
index b5fd87b..e85a326 100644
--- a/chrome/browser/net/preconnect.cc
+++ b/chrome/browser/net/preconnect.cc
@@ -37,7 +37,8 @@ void PreconnectOnIOThread(
const GURL& url,
UrlInfo::ResolutionMotivation motivation,
int count) {
- net::URLRequestContextGetter* getter = Profile::GetDefaultRequestContext();
+ net::URLRequestContextGetter* getter =
+ Profile::Deprecated::GetDefaultRequestContext();
if (!getter)
return;
if (!BrowserThread::CurrentlyOn(BrowserThread::IO)) {
diff --git a/chrome/browser/net/sdch_dictionary_fetcher.cc b/chrome/browser/net/sdch_dictionary_fetcher.cc
index 90f317a..6fc5bde 100644
--- a/chrome/browser/net/sdch_dictionary_fetcher.cc
+++ b/chrome/browser/net/sdch_dictionary_fetcher.cc
@@ -53,7 +53,8 @@ void SdchDictionaryFetcher::StartFetching() {
DCHECK(task_is_pending_);
task_is_pending_ = false;
- net::URLRequestContextGetter* context = Profile::GetDefaultRequestContext();
+ net::URLRequestContextGetter* context =
+ Profile::Deprecated::GetDefaultRequestContext();
if (!context) {
// Shutdown in progress.
// Simulate handling of all dictionary requests by clearing queue.
diff --git a/chrome/browser/net/websocket_experiment/websocket_experiment_task.cc b/chrome/browser/net/websocket_experiment/websocket_experiment_task.cc
index 6740e53..4933d40 100644
--- a/chrome/browser/net/websocket_experiment/websocket_experiment_task.cc
+++ b/chrome/browser/net/websocket_experiment/websocket_experiment_task.cc
@@ -35,10 +35,10 @@ static std::string GetProtocolVersionName(
URLFetcher* WebSocketExperimentTask::Context::CreateURLFetcher(
const Config& config, URLFetcher::Delegate* delegate) {
net::URLRequestContextGetter* getter =
- Profile::GetDefaultRequestContext();
- // Profile::GetDefaultRequestContext() is initialized lazily, on the UI
- // thread. So here, where we access it from the IO thread, if the task runs
- // before it has gotten lazily initialized yet.
+ Profile::Deprecated::GetDefaultRequestContext();
+ // Profile::Deprecated::GetDefaultRequestContext() is initialized lazily, on
+ // the UI thread. So here, where we access it from the IO thread, if the task
+ // runs before it has gotten lazily initialized yet.
if (!getter)
return NULL;
URLFetcher* fetcher =
@@ -54,10 +54,10 @@ URLFetcher* WebSocketExperimentTask::Context::CreateURLFetcher(
net::WebSocket* WebSocketExperimentTask::Context::CreateWebSocket(
const Config& config, net::WebSocketDelegate* delegate) {
net::URLRequestContextGetter* getter =
- Profile::GetDefaultRequestContext();
- // Profile::GetDefaultRequestContext() is initialized lazily, on the UI
- // thread. So here, where we access it from the IO thread, if the task runs
- // before it has gotten lazily initialized yet.
+ Profile::Deprecated::GetDefaultRequestContext();
+ // Profile::Deprecated::GetDefaultRequestContext() is initialized lazily, on
+ // the UI thread. So here, where we access it from the IO thread, if the task
+ // runs before it has gotten lazily initialized yet.
if (!getter)
return NULL;
net::WebSocket::Request* request(